#
# spec file for package hapistrano
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hapistrano
%bcond_with tests
Name:           %{pkg_name}
Version:        0.3.9.2
Release:        1.9
Summary:        A deployment library for Haskell applications
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-formatting-devel
BuildRequires:  ghc-gitrev-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-path-devel
BuildRequires:  ghc-path-io-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-typed-process-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-silently-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
Hapistrano makes it easy to reliably deploy Haskell applications to a server.

Following popular libraries like Ruby's <http://capistranorb.com/ Capistrano>,
Hapistrano does the work of building the application with dependencies into a
distinct folder, and then atomically moves a symlink to the latest complete
build.

This allows for atomic switchovers to new application code after the build is
complete. Rollback is even simpler, since Hapistrano can just point the
`current` symlink to the previous release.

See <https://github.com/stackbuilders/hapistrano the project readme on GitHub>
for more information. .

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Haskell
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGELOG.md Dockerfile README.md
%{_bindir}/hap
%dir %{_datadir}/%{name}-%{version}
%dir %{_datadir}/%{name}-%{version}/script
%{_datadir}/%{name}-%{version}/script/clean-build.sh

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md Dockerfile README.md

%changelog
* Tue Feb 12 2019 psimons@suse.com
- Update hapistrano to version 0.3.9.2.
  [#]# 0.3.9.2
  [#]## Changed
  * Update Docker base image from alpine:3.7 to alpine:3.9
* Sun Jan 27 2019 psimons@suse.com
- Update hapistrano to version 0.3.9.1.
  [#]# 0.3.9.1
  [#]## Added
  * Add timestamp to output commands:
  ```
  [16:29:58,  2019-01-23 (-05)] INFO -- : $ find /tmp/hapistrano/releases/ -maxdepth 1 -type d
  /tmp/hapistrano/releases/
  /tmp/hapistrano/releases/20190123212933
  ```
* Tue Jan 15 2019 psimons@suse.com
- Update hapistrano to version 0.3.9.0.
  [#]# 0.3.9.0
  [#]## Added
  * Support to deploy to a host that has default `zsh` shell.
  * Support to deploy using a different shell. Currently supported: `zsh` and `bash`.
  * `linked_files` and `linked_dirs` to link files and directories located in the
  `{deploy_path}/shared/` directory.
* Wed Dec 26 2018 psimons@suse.com
- Add hapistrano at version 0.3.8.0.
